/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.jcg.advisorapp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.ai.chat.client.advisor.api.AdvisedRequest;
import org.springframework.ai.chat.client.advisor.api.AdvisedResponse;
import org.springframework.ai.chat.client.advisor.api.CallAroundAdvisor;
import org.springframework.ai.chat.client.advisor.api.CallAroundAdvisorChain;
import org.springframework.stereotype.Component;

/**
 *
 * @author omozegieaziegbe
 */
@Component
public class ActivityLoggingAdvisor implements CallAroundAdvisor {

    private final static Logger logger = LoggerFactory.getLogger(ActivityLoggingAdvisor.class);

    @Override
    public AdvisedResponse aroundCall(AdvisedRequest advisedRequest, CallAroundAdvisorChain chain) {
        // Log the user's input before processing the request
        advisedRequest = this.logBeforeRequest(advisedRequest);

        // Continue with the next advisor in the chain
        AdvisedResponse advisedResponse = chain.nextAroundCall(advisedRequest);

        // Log the response content after processing the request
        logAfterResponse(advisedResponse);

        return advisedResponse;
    }

    private AdvisedRequest logBeforeRequest(AdvisedRequest advisedRequest) {
        // Log the prompt sent by the user
        logger.info("User Prompt: " + advisedRequest.userText());
        return advisedRequest;
    }

    private void logAfterResponse(AdvisedResponse advisedResponse) {
        // Log the response received from the AI model
        logger.info("AI Response: " + advisedResponse.response()
          .getResult()
          .getOutput()
          .getContent());
    }

    @Override
    public String getName() {
        return "ActivityLoggingAdvisor";
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
