/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.jcg.advisorapp;

/**
 *
 * @author omozegieaziegbe
 */
import org.springframework.stereotype.Service;
import java.util.List;
import org.springframework.ai.chat.client.ChatClient;
import org.springframework.ai.chat.client.advisor.QuestionAnswerAdvisor;
import org.springframework.ai.document.Document;
import org.springframework.ai.transformer.splitter.TokenTextSplitter;
import org.springframework.ai.vectorstore.VectorStore;

@Service
public class KnowledgeBasedChatService {

    private final ChatClient chatClient;
    private final VectorStore vectorDatabase;

    public KnowledgeBasedChatService(ChatClient.Builder chatClientBuilder, VectorStore vectorDatabase) {
        // Initialize a VectorStore with predefined knowledge
        this.vectorDatabase = vectorDatabase;
        Document initialKnowledge = new Document("Water boils at 100 degrees Celsius under normal atmospheric pressure.");
        List<Document> preparedDocuments = new TokenTextSplitter().apply(List.of(initialKnowledge));
        this.vectorDatabase.add(preparedDocuments);

        // Set up the QuestionAnswerAdvisor using the vector database
        QuestionAnswerAdvisor knowledgeAdvisor = new QuestionAnswerAdvisor(vectorDatabase);

        // Build the ChatClient with the advisor
        this.chatClient = chatClientBuilder.defaultAdvisors(knowledgeAdvisor).build();
    }

    public String handleKnowledgeQuery(String question) {
        return chatClient.prompt()
                         .user(question)
                         .call()
                         .content();
    }
}

